@@ -54,6 +54,7 @@ RefLogIter_iternext(RefLogIter *self)
 {
     const git_reflog_entry *entry;
     RefLogEntry *py_entry;
+    int err;
 
     if (self->i < self->size) {
         entry = git_reflog_entry_byindex(self->reflog, self->i);
@@ -62,8 +63,10 @@ RefLogIter_iternext(RefLogIter *self)
         py_entry->oid_old = git_oid_allocfmt(git_reflog_entry_id_old(entry));
         py_entry->oid_new = git_oid_allocfmt(git_reflog_entry_id_new(entry));
         py_entry->message = strdup(git_reflog_entry_message(entry));
-        py_entry->signature = git_signature_dup(
-            git_reflog_entry_committer(entry));
+        err = git_signature_dup(&py_entry->signature,
+                                git_reflog_entry_committer(entry));
+        if (err < 0)
+            return Error_set(err);
 
         ++(self->i);
 
@@ -160,7 +163,7 @@ Reference_rename(Reference *self, PyObject *py_name)
         return NULL;
 
     /* Rename */
-    err = git_reference_rename(&new_reference, self->reference, c_name, 0);
+    err = git_reference_rename(&new_reference, self->reference, c_name, 0, NULL, NULL);
     git_reference_free(self->reference);
     free(c_name);
     if (err < 0)
@@ -202,7 +205,10 @@ Reference_resolve(Reference *self, PyObject *args)
 PyDoc_STRVAR(Reference_target__doc__,
     "The reference target: If direct the value will be an Oid object, if it\n"
     "is symbolic it will be an string with the full name of the target\n"
-    "reference.");
+    "reference.\n"
+    "\n"
+    "The target is writable. Setting the Reference's target to another Oid\n"
+    "object will direct the reference to that Oid instead.");
 
 PyObject *
 Reference_target__get__(Reference *self)
@@ -240,7 +246,7 @@ Reference_target__set__(Reference *self, PyObject *py_target)
         if (err < 0)
             return err;
 
-        err = git_reference_set_target(&new_ref, self->reference, &oid);
+        err = git_reference_set_target(&new_ref, self->reference, &oid, NULL, NULL);
         if (err < 0)
             goto error;
 
@@ -254,7 +260,7 @@ Reference_target__set__(Reference *self, PyObject *py_target)
     if (c_name == NULL)
         return -1;
 
-    err = git_reference_symbolic_set_target(&new_ref, self->reference, c_name);
+    err = git_reference_symbolic_set_target(&new_ref, self->reference, c_name, NULL, NULL);
     free(c_name);
     if (err < 0)
         goto error;
