@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2013 The pygit2 contributors
+# Copyright 2010-2014 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -65,11 +65,10 @@ class BlameTest(utils.RepoTestCase):
             self.assertEqual(HUNKS[i][0], hunk.final_commit_id)
             self.assertEqual(HUNKS[i][1], hunk.final_start_line_number)
             self.assertEqualSignature(HUNKS[i][2], hunk.final_committer)
-            self.assertEqual(hunk.orig_commit_id,
-                            '0000000000000000000000000000000000000000')
+            self.assertEqual(HUNKS[i][0], hunk.orig_commit_id)
             self.assertEqual(hunk.orig_path, PATH)
             self.assertEqual(HUNKS[i][1], hunk.orig_start_line_number)
-            self.assertTrue(hunk.orig_committer is None)
+            self.assertEqualSignature(HUNKS[i][2], hunk.orig_committer)
             self.assertEqual(HUNKS[i][3], hunk.boundary)
 
     def test_blame_with_invalid_index(self):
@@ -93,11 +92,10 @@ class BlameTest(utils.RepoTestCase):
             self.assertEqual(HUNKS[i][0], hunk.final_commit_id)
             self.assertEqual(HUNKS[i][1], hunk.final_start_line_number)
             self.assertEqualSignature(HUNKS[i][2], hunk.final_committer)
-            self.assertEqual(hunk.orig_commit_id,
-                            '0000000000000000000000000000000000000000')
+            self.assertEqual(HUNKS[i][0], hunk.orig_commit_id)
             self.assertEqual(hunk.orig_path, PATH)
             self.assertEqual(HUNKS[i][1], hunk.orig_start_line_number)
-            self.assertTrue(hunk.orig_committer is None)
+            self.assertEqualSignature(HUNKS[i][2], hunk.orig_committer)
             self.assertEqual(HUNKS[i][3], hunk.boundary)
 
     def test_blame_with_invalid_line(self):
@@ -122,7 +120,7 @@ class BlameTest(utils.RepoTestCase):
 
         for rev, num_commits in revs:
             commit = repo.revparse_single(rev)
-            blame = repo.blame(PATH, newest_commit=commit.oid)
+            blame = repo.blame(PATH, newest_commit=commit.id)
 
             self.assertEqual(len(blame), num_commits)
 
@@ -131,11 +129,10 @@ class BlameTest(utils.RepoTestCase):
                 self.assertEqual(HUNKS[i][0], hunk.final_commit_id)
                 self.assertEqual(HUNKS[i][1], hunk.final_start_line_number)
                 self.assertEqualSignature(HUNKS[i][2], hunk.final_committer)
-                self.assertEqual(hunk.orig_commit_id,
-                                '0000000000000000000000000000000000000000')
+                self.assertEqual(HUNKS[i][0], hunk.orig_commit_id)
                 self.assertEqual(hunk.orig_path, PATH)
                 self.assertEqual(HUNKS[i][1], hunk.orig_start_line_number)
-                self.assertTrue(hunk.orig_committer is None)
+                self.assertEqualSignature(HUNKS[i][2], hunk.orig_committer)
                 self.assertEqual(HUNKS[i][3], hunk.boundary)
 
 if __name__ == '__main__':
